use bevy::prelude::*;

use super::velocity::Velocity;

pub struct AnimationPlugin;

impl Plugin for AnimationPlugin {
	fn build(&self, app: &mut App) {
		app.add_systems(FixedUpdate, animation_tick);
	}
}

#[derive(Bundle, Default)]
pub struct AnimationBundle {
	pub timer: AnimationTimer,

	pub atlas: TextureAtlas,

	pub indices: AnimationIndices,
}

#[derive(Component, Default)]
pub struct AnimationIndices {
	pub first_index: usize,
	pub last_index: usize,
}

#[derive(Component, Default, Deref, DerefMut)]
pub struct AnimationTimer(pub Timer);

fn animation_tick(
	time: Res<Time>,
	mut query: Query<(
		&mut AnimationTimer,
		&mut TextureAtlas,
		&AnimationIndices,
		&Velocity,
	)>,
) {
	for (mut timer, mut atlas, anim_indicies, velocity) in &mut query {
		if velocity.length() > 0.0 {
			timer.tick(time.delta());
			if timer.just_finished() {
				atlas.index = if atlas.index == anim_indicies.last_index {
					anim_indicies.first_index
				}
				else {
					atlas.index + 1
				}
			}
		}
	}
}
